@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "dialogguard.h"
 
 // Qt
-#include <QDebug>
+#include "gwenview_importer_debug.h"
 #include <QDir>
 #include <QIcon>
 #include <QPushButton>
