@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // Qt
 #include <QDBusObjectPath>
 #include <QAction>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 namespace Gwenview
 {
